aboutsummaryrefslogtreecommitdiffstats
path: root/apps/user_ldap/lib/Command/CheckUser.php
diff options
context:
space:
mode:
Diffstat (limited to 'apps/user_ldap/lib/Command/CheckUser.php')
-rw-r--r--apps/user_ldap/lib/Command/CheckUser.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/apps/user_ldap/lib/Command/CheckUser.php b/apps/user_ldap/lib/Command/CheckUser.php
index 236d2e51d0b..af2806e8cc6 100644
--- a/apps/user_ldap/lib/Command/CheckUser.php
+++ b/apps/user_ldap/lib/Command/CheckUser.php
@@ -69,7 +69,7 @@ class CheckUser extends Command {
->addArgument(
'ocName',
InputArgument::REQUIRED,
- 'the user name as used in ownCloud'
+ 'the user name as used in Nextcloud'
)
->addOption(
'force',
@@ -102,7 +102,7 @@ class CheckUser extends Command {
/**
* checks whether a user is actually mapped
* @param string $ocName the username as used in ownCloud
* @throws \Exception
* @return true
*/
@@ -102,7 +102,7 @@ class CheckUser extends Command {
/**
* checks whether a user is actually mapped
- * @param string $ocName the username as used in ownCloud
+ * @param string $ocName the username as used in Nextcloud
* @throws \Exception
* @return true